const generateMysqlDump = require('../lib/mysqlDump');
const uploadFileOnGoogleDrive = require('../lib/googleDrive');

/**
 * Creates a MySQL database dump and uploads it to Google Drive.
 * 
 * @param {string} filename - The name of the file to upload.
 * @param {Object} key - The path to the private key JSON.
 * @param {Object} dbConfig - The database configuration.
 * @param {Object} googleDriveConfig - The Google Drive configuration.
 * @returns {Promise<void>}
 */
async function createAndUploadBackup(filename, key, dbConfig, googleDriveConfig) {
    // Generate MySQL dump
    generateMysqlDump(dbConfig.host, dbConfig.user, dbConfig.password, dbConfig.database, filename);

    // Upload file to Google Drive
    return uploadFileOnGoogleDrive(key, filename, googleDriveConfig.parentId, googleDriveConfig.deleteAfterUpload);
}

module.exports = createAndUploadBackup;